@@ -201,7 +201,7 @@ class ClsClient(AbstractClient):
 
 
     def CreateExport(self, request):
-        """This API is used to create a download task to export raw logs.
+        """This API is used to create a download task. To get the returned download address, call `DescribeExports` to view the task list. The `CosPath` parameter is also included for download address. For more information, visit https://intl.cloud.tencent.com/document/product/614/56449.?from_cn_redirect=1
 
         :param request: Request instance for CreateExport.
         :type request: :class:`tencentcloud.cls.v20201016.models.CreateExportRequest`
