@@ -62,6 +62,9 @@ FAILEDOPERATION_TASKDUPLICATE = 'FailedOperation.TaskDuplicate'
 # Operation failed: failed to upload file to COS.
 FAILEDOPERATION_UPLOADCOSFAIL = 'FailedOperation.UploadCosFail'
 
+# The service has been suspended.
+FAILEDOPERATION_USERSTATUSINAVLID = 'FailedOperation.UserStatusInavlid'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
